@@ -82,7 +82,7 @@ class AWeberCollection(AWeberResponse):
     def _get_total_size(self, uri, **kwargs):
         """Get actual total size number from total_size_link."""
         total_size_uri = '{0}&ws.show=total_size'.format(uri)
-        return self.adapter.request('GET', total_size_uri)
+        return int(self.adapter.request('GET', total_size_uri))
 
     def get_parent_entry(self):
         """Return a collection's parent entry or None."""
